Documentation
¶
Index ¶
- Constants
- func CodexAppLaunchTarget() (string, error)
- func ResolveLaunchBinary(appID, binaryName string) (string, bool)
- func SetCodexAppLaunchTarget(target string) error
- func XiaozhiURL() string
- func ZCodeLaunchTarget() (string, error)
- type LogBuffer
- type Manager
- func (m *Manager) EnrichCachedLatestVersion(info *api.AIAppInfo)
- func (m *Manager) EnrichLatestVersion(ctx context.Context, info *api.AIAppInfo)
- func (m *Manager) Get(ctx context.Context, appID string) (api.AIAppInfo, error)
- func (m *Manager) Install(appID string) (api.AIAppInfo, error)
- func (m *Manager) List(ctx context.Context) ([]api.AIAppInfo, error)
- func (m *Manager) RecentLogs(appID string, n int) ([]string, error)
- func (m *Manager) RefreshAll(ctx context.Context) error
- func (m *Manager) RefreshLatestVersionAsync(info api.AIAppInfo)
- func (m *Manager) StartXiaozhi(ctx context.Context) error
- func (m *Manager) StopXiaozhi(ctx context.Context) error
- func (m *Manager) SubscribeLogs(appID string) (chan string, error)
- func (m *Manager) Uninstall(appID string) (api.AIAppInfo, error)
- func (m *Manager) UnsubscribeLogs(appID string, ch chan string)
- func (m *Manager) XiaozhiRunning(ctx context.Context) (bool, error)
- type SourceSwitchManager
- func (m *SourceSwitchManager) RestoreNative(group, targetPath string, isManaged func([]byte) bool, ...) (SourceSwitchStatus, error)
- func (m *SourceSwitchManager) Status(group, targetPath string, isManaged func([]byte) bool) (SourceSwitchStatus, error)
- func (m *SourceSwitchManager) UseOpenCSG(group, targetPath string, isManaged func([]byte) bool, apply func() error) (SourceSwitchStatus, error)
- type SourceSwitchStatus
Constants ¶
const ( ProviderModeNative = "native" ProviderModeOpenCSG = "opencsg" )
Variables ¶
This section is empty.
Functions ¶
func CodexAppLaunchTarget ¶ added in v0.9.5
CodexAppLaunchTarget resolves the local Codex App bundle path for desktop launch.
func ResolveLaunchBinary ¶ added in v0.9.5
ResolveLaunchBinary returns a launchable binary path using the same lookup profile that install detection uses.
func SetCodexAppLaunchTarget ¶ added in v0.9.16
SetCodexAppLaunchTarget records a user-specified Codex App location in the launch-target file, which sits at the top of the detection and launch resolution order. This is the manual escape hatch for installs that live outside every scanned location.
func XiaozhiURL ¶ added in v0.9.20
func XiaozhiURL() string
func ZCodeLaunchTarget ¶ added in v0.9.19
ZCodeLaunchTarget resolves a managed or externally installed ZCode desktop target.
Types ¶
type LogBuffer ¶
type LogBuffer struct {
// contains filtered or unexported fields
}
func NewLogBuffer ¶
func (*LogBuffer) Unsubscribe ¶
type Manager ¶
type Manager struct {
// contains filtered or unexported fields
}
func NewManager ¶
func (*Manager) EnrichCachedLatestVersion ¶
func (*Manager) EnrichLatestVersion ¶
func (*Manager) RefreshLatestVersionAsync ¶
func (*Manager) StartXiaozhi ¶ added in v0.9.20
func (*Manager) StopXiaozhi ¶ added in v0.9.20
func (*Manager) UnsubscribeLogs ¶
type SourceSwitchManager ¶ added in v0.9.25
type SourceSwitchManager struct {
// contains filtered or unexported fields
}
func NewSourceSwitchManager ¶ added in v0.9.25
func NewSourceSwitchManager(storageRoot string) *SourceSwitchManager
func (*SourceSwitchManager) RestoreNative ¶ added in v0.9.25
func (m *SourceSwitchManager) RestoreNative( group, targetPath string, isManaged func([]byte) bool, restoreLegacy func() error, ) (SourceSwitchStatus, error)
func (*SourceSwitchManager) Status ¶ added in v0.9.25
func (m *SourceSwitchManager) Status(group, targetPath string, isManaged func([]byte) bool) (SourceSwitchStatus, error)
func (*SourceSwitchManager) UseOpenCSG ¶ added in v0.9.25
func (m *SourceSwitchManager) UseOpenCSG( group, targetPath string, isManaged func([]byte) bool, apply func() error, ) (SourceSwitchStatus, error)
type SourceSwitchStatus ¶ added in v0.9.25
Click to show internal directories.
Click to hide internal directories.