apps

package
v0.9.13 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 7, 2026 License: Apache-2.0 Imports: 22 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func CodexAppLaunchTarget added in v0.9.5

func CodexAppLaunchTarget() (string, error)

CodexAppLaunchTarget resolves the local Codex App bundle path for desktop launch.

func ResolveLaunchBinary added in v0.9.5

func ResolveLaunchBinary(appID, binaryName string) (string, bool)

ResolveLaunchBinary returns a launchable binary path using the same lookup profile that install detection uses.

Types

type LogBuffer

type LogBuffer struct {
	// contains filtered or unexported fields
}

func NewLogBuffer

func NewLogBuffer(maxSize int) *LogBuffer

func (*LogBuffer) Append

func (lb *LogBuffer) Append(line string)

func (*LogBuffer) Recent

func (lb *LogBuffer) Recent(n int) []string

func (*LogBuffer) Reset

func (lb *LogBuffer) Reset()

func (*LogBuffer) Subscribe

func (lb *LogBuffer) Subscribe() chan string

func (*LogBuffer) Unsubscribe

func (lb *LogBuffer) Unsubscribe(ch chan string)

type Manager

type Manager struct {
	// contains filtered or unexported fields
}

func NewManager

func NewManager(cfg *config.Config) *Manager

func (*Manager) EnrichCachedLatestVersion

func (m *Manager) EnrichCachedLatestVersion(info *api.AIAppInfo)

func (*Manager) EnrichLatestVersion

func (m *Manager) EnrichLatestVersion(ctx context.Context, info *api.AIAppInfo)

func (*Manager) Get

func (m *Manager) Get(ctx context.Context, appID string) (api.AIAppInfo, error)

func (*Manager) Install

func (m *Manager) Install(appID string) (api.AIAppInfo, error)

func (*Manager) List

func (m *Manager) List(ctx context.Context) ([]api.AIAppInfo, error)

func (*Manager) RecentLogs

func (m *Manager) RecentLogs(appID string, n int) ([]string, error)

func (*Manager) RefreshAll

func (m *Manager) RefreshAll(ctx context.Context) error

func (*Manager) RefreshLatestVersionAsync

func (m *Manager) RefreshLatestVersionAsync(info api.AIAppInfo)

func (*Manager) SubscribeLogs

func (m *Manager) SubscribeLogs(appID string) (chan string, error)

func (*Manager) Uninstall

func (m *Manager) Uninstall(appID string) (api.AIAppInfo, error)

func (*Manager) UnsubscribeLogs

func (m *Manager) UnsubscribeLogs(appID string, ch chan string)

Jump to